@@ -11,7 +11,7 @@ my %type;
 my %kind;
 while ( my $record = $dump->next_record() ) {
     $type{ $record->type() }++;
-    $kind{ $record->get_headers()->{'Node-action'} }++
+    $kind{ $record->get_header('Node-action') }++
         if $record->type() eq 'node';
 }
 
