@@ -3,10 +3,19 @@ package SVN::Dump::Headers;
 use strict;
 use warnings;
 use Carp;
+use Scalar::Util qw( reftype );
 
 my $NL = "\012";
 
-sub new { return bless {}, shift; }
+sub new {
+    my ( $class, $headers ) = @_;
+    croak 'First parameter must be a HASH reference'
+        if defined $headers
+        && !( ref $headers && reftype $headers eq 'HASH' );
+    my $self = bless {}, $class;
+    $self->set( $_ => $headers->{$_} ) for keys %{ $headers || {} };
+    return $self;
+}
 
 my %headers = (
     revision => [
@@ -27,9 +36,11 @@ my %headers = (
             Prop-delta
             Prop-content-length
             Text-copy-source-md5
+            Text-copy-source-sha1
             Text-delta
             Text-content-length
             Text-content-md5
+            Text-content-sha1
             Content-length
             )
     ],
@@ -68,11 +79,13 @@ sub set {
     my ($self, $h, $v) = @_;
 
     # FIXME shall we check that the header value is valid?
+    $h =~ tr/_/-/; # allow _ for - simplification
     return $self->{$h} = $v;
 }
 
 sub get {
     my ($self, $h) = @_;
+    $h =~ tr/_/-/; # allow _ for - simplification
     return $self->{$h};
 }
 
@@ -91,29 +104,39 @@ SVN::Dump::Headers - Headers of a SVN dump record
 
 =head1 SYNOPSIS
 
+    # SVN::Dump::Headers objects are returned by the read_header_block()
+    # method of SVN::Dump::Reader
+
 =head1 DESCRIPTION
 
-An C<SVN::Dump::Headers> object represents the headers of a
+A SVN::Dump::Headers object represents the headers of a
 SVN dump record.
 
 =head1 METHODS
 
-C<SVN::Dump::Headers> provides the following methods:
+SVN::Dump::Headers provides the following methods:
 
 =over 4
 
-=item new()
+=item new( [$hashref] )
 
-Create and return a new empty C<SVN::Dump::Headers> object.
+Create and return a new empty L<SVN::Dump::Headers> object.
+
+If C<$hashref> is given (it can be a blessed hash reference), the
+keys from the hash are used to initialise the headers.
 
 =item set($h, $v)
 
 Set the C<$h> header to the value C<$v>.
 
+C<_> can be used as a replacement for C<-> in the header name.
+
 =item get($h)
 
 Get the value of header C<$h>.
 
+C<_> can be used as a replacement for C<-> in the header name.
+
 =item keys()
 
 Return the list of headers, in canonical order.
@@ -135,20 +158,23 @@ The method dies if it can't determine the record type.
 
 =head1 ENCAPSULATION
 
-When using C<SVN::Dump> to manipulate a SVN dump, one should not directly
-access the C<SVN::Dump::Headers> component of a C<SVN::Dump::Record>, but
+When using L<SVN::Dump> to manipulate a SVN dump, one should not directly
+access the L<SVN::Dump::Headers> component of a L<SVN::Dump::Record>, but
 use the C<set_header()> and C<get_header()> methods of the record object.
 
 =head1 SEE ALSO
 
-C<SVN::Dump::Record>.
+L<SVN::Dump>,
+L<SVN::Dump::Reader>,
+L<SVN::Dump::Record>.
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT
 
-Copyright 2006 Philippe 'BooK' Bruhat, All Rights Reserved.
+Copyright 2006-2011 Philippe Bruhat (BooK), All Rights Reserved.
+
+=head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
